SystemOrganization addCategory: #VisualIDs!
SystemOrganization addCategory: #'VisualIDs-Test'!

TestCase subclass: #RandomFunctionsTest
	instanceVariableNames: 'r'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VisualIDs-Test'!

!RandomFunctionsTest methodsFor: 'setup' stamp: 'EduardoEscobar 12/15/2011 01:27'!
setUp
	r := RandomFunctions new! !

!RandomFunctionsTest methodsFor: 'tests' stamp: 'EduardoEscobar 12/15/2011 01:13'!
testRnd
	100 timesRepeat: [ 
			| n |
			n := r rnd.
			self assert: n >= 0.
			self assert: n < 1 ]! !

!RandomFunctionsTest methodsFor: 'tests' stamp: 'EduardoEscobar 12/15/2011 01:13'!
testRnd11
	100 timesRepeat: [ 
			| n |
			n := r rnd11.
			self assert: n >= -1.
			self assert: n < 1 ]! !

!RandomFunctionsTest methodsFor: 'tests' stamp: 'EduardoEscobar 12/15/2011 01:12'!
testRndin
	100 timesRepeat: [ 
			| n |
			n := r rndin: 1 to: 10.
			self assert: n >= 1.
			self assert: n < 10 ]! !

!RandomFunctionsTest methodsFor: 'tests' stamp: 'EduardoEscobar 12/16/2011 12:24'!
testRndinLevel
	100 timesRepeat: [ 
			| n |
			n := r rndinLevel: 1 to: 20 level: 1.
			self assert: n >= 1.
			self assert: n < 20 ]! !

!RandomFunctionsTest methodsFor: 'tests' stamp: 'EduardoEscobar 12/15/2011 01:17'!
testRndinLowbias
	100 timesRepeat: [ 
			| n |
			n := r rndinLowbias: 1 to: 10.
			self assert: n >= 1.
			self assert: n < 10 ].
	100 timesRepeat: [ 
			| n |
			n := r rndinLowbias: 1 to: 10 with: 0.5.
			self assert: n >= 1.
			self assert: n < 10 ]! !

!RandomFunctionsTest methodsFor: 'tests' stamp: 'EduardoEscobar 12/16/2011 12:27'!
testRndprobLevel
	100 timesRepeat: [ 
			| p |
			p := r rnd.
			self assert: p>(r rndprobLevel: p level: 1) ]! !

Object subclass: #AlongAPath
	instanceVariableNames: 'hasChild Cscale n fourier exponent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VisualIDs'!

!AlongAPath methodsFor: 'initialization' stamp: 'EduardoEscobar 12/21/2011 18:17'!
initialize: level
	"initialize"

	| rnd |
	rnd := RandomFunctions new.
	hasChild := rnd rndprobLevel: 0.8 level: level.
	Cscale := rnd rndin: 0.1 to: 0.6.
	n := rnd rndinLevel: 3 to: 6 level: level.
	fourier := rnd rndprob: 0.5.
	exponent := rnd rndin: 1.6 to: 2.2! !

Object subclass: #AroundASpiral
	instanceVariableNames: 'len aligned ppr hasChild centerScale outerScale'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VisualIDs'!

!AroundASpiral methodsFor: 'initialization' stamp: 'EduardoEscobar 12/16/2011 12:23'!
initialize: level
	"initialize"

	| rnd |
	rnd := RandomFunctions new.
	level = 1
		ifTrue: [ len := rnd rndin: 25 to: 60 ]
		ifFalse: [ 
			level = 2
				ifTrue: [ len := rnd rndin: 10 to: 30 ]
				ifFalse: [ 
					level = 3
						ifTrue: [ len := rnd rndin: 5 to: 10 ]
						ifFalse: [ len := 5 ] ] ].
	aligned := rnd rndprob: 0.5.
	aligned
		ifTrue: [ ppr := rnd rndinLowbias: 3 to: 35 ]
		ifFalse: [ ppr := rnd rational: 3 to: 35 denominal: (rnd rndin: 3 to: 7) ].
	hasChild := rnd rndin: 0.5 to: 1.
	centerScale := rnd rndin: 0.05 to: 0.6.
	outerScale := rnd rndin: 0.25 to: 1! !

Object subclass: #FigureGenerator
	instanceVariableNames: 'headScale legScale tailScale'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VisualIDs'!

!FigureGenerator methodsFor: 'as yet unclassified' stamp: 'EduardoEscobar 12/21/2011 18:35'!
initialize
	"initialize"

	| rnd |
	rnd := RandomFunctions new.
	headScale := rnd rndin: 0.1 to: 0.2.
	legScale := rnd rndin: 0.3 to: 0.6.
	tailScale := rnd rndin: 0.1 to: 0.4! !

Object subclass: #LineGenerator
	instanceVariableNames: 'len n hasEC1 hasEC2 hasC3 C1scale C2scale C3scale C3doublesided C3angle C3taper C3increase'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VisualIDs'!

!LineGenerator methodsFor: 'initialization' stamp: 'EduardoEscobar 12/21/2011 19:01'!
initialize
	"initialize"

	| rnd |
	rnd := RandomFunctions new.
	len := rnd rndin: 0.5 to: 1.
	n := rnd rndinLowbias: 3 to: 10 with: 1.5.
	hasEC1 := rnd rndprob: 0.75.
	hasEC2 := rnd rndprob: 0.75.
	hasC3 := rnd rndprob: 0.5.
	C1scale := rnd rndin: 0.15 to: 0.6.
	C2scale := rnd rndin: 0.15 to: 0.6.
	C3scale := rnd rndinLowbias: 0.05 to: 0.7 with: 1.5.
	C3doublesided := rnd rndprob: 0.8.
	C3angle := rnd rndin: -3.141592 / 4 to: 3.141592 / 4.	"Pi=3.141592"
	C3taper := rnd rndprob: 0.3.
	C3increase := rnd rndprob: 0.3! !

Object subclass: #Radial
	instanceVariableNames: 'n hasVertex VCscale hasMouth MCscale mouthOrg hasEyes ECscale eyeSep eyeOrg angleCut angleCutoff'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VisualIDs'!

!Radial methodsFor: 'initialization' stamp: 'EduardoEscobar 12/15/2011 00:28'!
initialize
	"initialize"

	| rnd |
	rnd := RandomFunctions new.
	n := rnd rndinLowbias: 3 to: 12.
	hasVertex := rnd rndprob: 0.5.
	VCscale := rnd rndin: 0.15 to: 0.7.
	hasMouth := rnd rndprob: 0.6.
	MCscale := rnd rndin: 0.1 to: 0.3.
	hasEyes := rnd rndprob: 0.3.
	mouthOrg := rnd rndin: -0.2 to: -0.3. "sale un if hasEyes segun el documento"
	ECscale := rnd rndin: 0.1 to: 0.4.
	eyeSep := rnd rndin: 0.2 to: 0.3.
	eyeOrg := rnd rndin: 0.2 to: 0.3.
	angleCut := rnd rndprob: 0.5.
	angleCutoff := rnd rndin: 90 to: 150! !

Object subclass: #RandomFunctions
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VisualIDs'!

!RandomFunctions methodsFor: 'initialization' stamp: 'EduardoEscobar 12/19/2011 23:04'!
initialize
	"initialize"! !

!RandomFunctions methodsFor: 'methods' stamp: 'EduardoEscobar 12/16/2011 12:21'!
rational: a to: b denominal: denominator
	"comment stating purpose of message"

	^(((RandomFunctions new rndin: a to: b) rounded)/denominator) ! !

!RandomFunctions methodsFor: 'methods' stamp: 'EduardoEscobar 12/15/2011 00:03'!
rnd
	"returns a random value in [0,1)"

	^ Random new next! !

!RandomFunctions methodsFor: 'methods' stamp: 'EduardoEscobar 12/15/2011 00:38'!
rnd11
	"returns a uniform pseudo-random value in -1,1."

	^ -1 + (Random new next * (1 - -1))! !

!RandomFunctions methodsFor: 'methods' stamp: 'EduardoEscobar 12/14/2011 21:22'!
rndin: a to: b
	"returns a random value in [a,b]"
	^(a + ((Random new next) * (b - a)))! !

!RandomFunctions methodsFor: 'methods' stamp: 'EduardoEscobar 12/16/2011 12:06'!
rndinLevel: a to: b level: level
	"the range is reduced by recursion level, i.e., a + Rnd()*(b-a)/level."

	| c |
	c := Random new next.
	^ a + (c * (b - a) / level)! !

!RandomFunctions methodsFor: 'methods' stamp: 'EduardoEscobar 12/14/2011 22:00'!
rndinLowbias: a to: b
	"return a pseudo-random value (i.e., a + rnd^2*(b-a))"
	|c|
	c:=(Random new next).
	^(a + ((c*c) * (b - a)))! !

!RandomFunctions methodsFor: 'methods' stamp: 'EduardoEscobar 12/15/2011 00:47'!
rndinLowbias: a to: b with: p
	"is a version of the low-bias generator where the power can be specified: a + (b-a)*pow(Rnd(),p)."

	| c |
	c := Random new next.
	^ a + ((b - a) * c raisedTo: p)! !

!RandomFunctions methodsFor: 'methods' stamp: 'EduardoEscobar 12/15/2011 00:09'!
rndprob: p
	"returns true if rnd is greater than p"

	^ Random new next > p! !

!RandomFunctions methodsFor: 'methods' stamp: 'EduardoEscobar 12/16/2011 12:07'!
rndprobLevel: p level: level
	"The probability is reduced at each level using p = p - p*min(level,5)/6"

	^ p - (p * (5 min: level) / 6)! !

Object subclass: #Scribble
	instanceVariableNames: 'zigzag n friction'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VisualIDs'!

!Scribble methodsFor: 'initialization' stamp: 'EduardoEscobar 12/21/2011 18:29'!
initialize: level
	"initialize"

	| rnd |
	rnd := RandomFunctions new.
	zigzag := rnd rndprob: 0.5.
	zigzag
		ifTrue: [ n := rnd rndin: 40 to: 10 ]
		ifFalse: [ 
			level = 1
				ifTrue: [ n := rnd rndin: 2 to: 30 ]
				ifFalse: [ n := rnd rndin: 10 to: 20 ] ].
	zigzag
		ifTrue: [ friction := rnd rndin: 0.8 to: 0.9 ]
		ifFalse: [ rnd rndin: 0.85 to: 0.98 ]! !

Object subclass: #Symmetry
	instanceVariableNames: 'n offset offsetTrans Cscale'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VisualIDs'!
